import { StartCollectingRequestsRequest as StartCollectingRequestsRequest$1, StartCollectingRequestsResponse as StartCollectingRequestsResponse$1, StopCollectingRequestsRequest as StopCollectingRequestsRequest$1, StopCollectingRequestsResponse as StopCollectingRequestsResponse$1, GetSettingsRequest as GetSettingsRequest$1, GetSettingsResponse as GetSettingsResponse$1 } from './index.typings.js';
import '@wix/sdk-types';

/**
 * The back in stock settings object holds information related to the state of collecting back in stock
 * notification requests ([SDK](https://dev.wix.com/docs/sdk/backend-modules/ecom/back-in-stock-notifications/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/e-commerce/other-services/back-in-stock/back-in-stock-notifications/introduction)).
 */
interface BackInStockSettings {
    /**
     * Information about collecting customer requests to receive
     * back in stock notifications.
     */
    collectionStates?: BackInStockCollectionState[];
}
interface BackInStockCollectionState {
    /**
     * ID of the app to receive notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId?: string;
    /** Whether to collect requests for items from this app. */
    collectingRequests?: boolean;
}
interface StartCollectingRequestsRequest {
    /**
     * ID of the app to start accepting notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId: string;
}
interface StartCollectingRequestsResponse {
    /** Back in stock settings info. */
    settings?: BackInStockSettings;
}
interface StopCollectingRequestsRequest {
    /**
     * ID of the app to stop accepting notification requests for.
     *
     * Back in stock notifications only work for [Wix Stores](https://support.wix.com/en/article/wix-stores-about-wix-stores).
     * The `appId` for Wix Stores is `"215238eb-22a5-4c36-9e7b-e7c08025e04e"`.
     * @format GUID
     */
    appId: string;
}
interface StopCollectingRequestsResponse {
    /** Back in stock settings info. */
    settings?: BackInStockSettings;
}
interface GetSettingsRequest {
}
interface GetSettingsResponse {
    /** Retrieved back in stock request settings. */
    settings?: BackInStockSettings;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function startCollectingRequests(): __PublicMethodMetaInfo<'POST', {}, StartCollectingRequestsRequest$1, StartCollectingRequestsRequest, StartCollectingRequestsResponse$1, StartCollectingRequestsResponse>;
declare function stopCollectingRequests(): __PublicMethodMetaInfo<'POST', {}, StopCollectingRequestsRequest$1, StopCollectingRequestsRequest, StopCollectingRequestsResponse$1, StopCollectingRequestsResponse>;
declare function getSettings(): __PublicMethodMetaInfo<'PUT', {}, GetSettingsRequest$1, GetSettingsRequest, GetSettingsResponse$1, GetSettingsResponse>;

export { type __PublicMethodMetaInfo, getSettings, startCollectingRequests, stopCollectingRequests };
